def test_importing_package_main():
    """Test that simply importing the application works. This checks for any dependency issues."""
    from auto_py_to_exe import __main__ as auto_py_to_exe_main  # noqa: F401



import os
import subprocess

from helpers import PythonScriptAsFile, TemporaryDirectory, os_allow

from auto_py_to_exe import config as auto_py_to_exe_config
from auto_py_to_exe.packaging import package


@os_allow(["Windows"])
def test_basic_packaging():
    """Test a basic packaging setup on Windows"""
    filename = "script.py"
    content = 'print("Test")'

    with TemporaryDirectory() as build_directory:
        auto_py_to_exe_config.temporary_directory = build_directory

        with TemporaryDirectory() as output_directory:
            with PythonScriptAsFile(filename, content) as script_path:
                pyinstaller_command = 'pyinstaller --noconfirm --onedir --nowindowed "{}"'.format(script_path)
                options = {"increaseRecursionLimit": False, "outputDirectory": output_directory}

                success = package(pyinstaller_command, options)
                assert success

                predicted_output_folder = os.path.join(output_directory, filename.split(".")[0])
                assert os.path.exists(predicted_output_folder) and os.path.isdir(predicted_output_folder)

                predicted_exe_location = os.path.join(predicted_output_folder, filename.split(".")[0] + ".exe")
                exe_output = subprocess.check_output([predicted_exe_location], cwd=predicted_output_folder)
                assert exe_output == b"Test\r\n"



def test_eel_functions_and_variables_exist():
    """Test that the functions and variables that we use from Eel exist."""
    import eel

    # Functions we use for their actions
    assert hasattr(eel, "init")
    assert callable(eel.init)
    assert hasattr(eel, "expose")
    assert callable(eel.expose)
    assert hasattr(eel, "start")
    assert callable(eel.start)

    # Functions we use for their value
    from eel import chrome

    chrome_path = chrome.find_path()
    assert chrome_path is None or isinstance(chrome_path, str)


def test_pyinstaller_functions_and_variables_exist():
    """Test that the functions and variables that we use from PyInstaller exist."""

    # Functions we use for their actions
    import PyInstaller.__main__ as pyi_main

    assert hasattr(pyi_main, "run")
    assert callable(pyi_main.run)

    # Variables we use
    import PyInstaller as pyi

    assert isinstance(pyi.__version__, str)
